@@ -4,6 +4,7 @@ from benedict.core import clean as _clean
 from benedict.core import clone as _clone
 from benedict.core import dump as _dump
 from benedict.core import filter as _filter
+from benedict.core import find as _find
 from benedict.core import flatten as _flatten
 from benedict.core import groupby as _groupby
 from benedict.core import invert as _invert
@@ -28,14 +29,30 @@ from benedict.dicts.keypath import KeypathDict
 from benedict.dicts.parse import ParseDict
 
 
-class benedict(IODict, KeypathDict, ParseDict):
+class benedict(KeypathDict, IODict, ParseDict):
 
     def __init__(self, *args, **kwargs):
         """
         Constructs a new instance.
         """
+        if len(args) == 1 and isinstance(args[0], benedict):
+            super(benedict, self).__init__(args[0].dict())
+            return
         super(benedict, self).__init__(*args, **kwargs)
 
+    def __getitem__(self, key):
+        return self._cast(
+            super(benedict, self).__getitem__(key))
+
+    def _cast(self, value):
+        """
+        Cast a dict instance to a benedict instance
+        keeping the pointer to the original dict.
+        """
+        if isinstance(value, dict) and not isinstance(value, benedict):
+            return benedict(value, keypath_separator=self._keypath_separator)
+        return value
+
     def clean(self, strings=True, collections=True):
         """
         Clean the current dict instance removing all empty values: None, '', {}, [], ().
@@ -48,17 +65,15 @@ class benedict(IODict, KeypathDict, ParseDict):
         """
         Creates and return a clone of the current dict instance (deep copy).
         """
-        return benedict(
-            _clone(self),
-            keypath_separator=self._keypath_separator)
+        return self._cast(
+            _clone(self))
 
     def copy(self):
         """
         Creates and return a copy of the current instance (shallow copy).
         """
-        return benedict(
-            super(benedict, self).copy(),
-            keypath_separator=self._keypath_separator)
+        return self._cast(
+            super(benedict, self).copy())
 
     def deepcopy(self):
         """
@@ -86,6 +101,13 @@ class benedict(IODict, KeypathDict, ParseDict):
         """
         return _filter(self, predicate)
 
+    def find(self, keys, default=None):
+        """
+        Return the first match searching for the given keys.
+        If no result found, default value is returned.
+        """
+        return _find(self, keys, default)
+
     def flatten(self, separator='_'):
         """
         Return a new flattened dict using the given separator
@@ -93,11 +115,24 @@ class benedict(IODict, KeypathDict, ParseDict):
         """
         return _flatten(self, separator)
 
+    def get(self, key, default=None):
+        return self._cast(
+            super(benedict, self).get(key, default))
+
+    def get_dict(self, key, default=None):
+        return self._cast(
+            super(benedict, self).get_dict(key, default))
+
+    def get_list_item(self, key, index=0, default=None, separator=','):
+        return self._cast(
+            super(benedict, self).get_list_item(key, index, default, separator))
+
     def groupby(self, key, by_key):
         """
         Group a list of dicts at key by the value of the given by_key and return a new dict.
         """
-        return benedict(_groupby(self[key], by_key))
+        return self._cast(
+            _groupby(self[key], by_key))
 
     def invert(self, flat=False):
         """
@@ -128,12 +163,13 @@ class benedict(IODict, KeypathDict, ParseDict):
         sep = self._keypath_separator or '.'
         return _keypaths(self, separator=sep)
 
-    def merge(self, other, *args):
+    def merge(self, other, *args, **kwargs):
         """
         Merge one or more dict objects into current instance (deepupdate).
         Sub-dictionaries will be merged toghether.
+        If overwrite is False, existing values will not be overwritten.
         """
-        _merge(self, other, *args)
+        _merge(self, other, *args, **kwargs)
 
     def move(self, key_src, key_dest):
         """
@@ -149,6 +185,10 @@ class benedict(IODict, KeypathDict, ParseDict):
         """
         return _nest(self[key], id_key, parent_id_key, children_key)
 
+    def pop(self, key, *args):
+        return self._cast(
+            super(benedict, self).pop(key, *args))
+
     def remove(self, keys, *args):
         """
         Remove multiple keys from the current dict instance.
@@ -156,6 +196,10 @@ class benedict(IODict, KeypathDict, ParseDict):
         """
         _remove(self, keys, *args)
 
+    def setdefault(self, key, default=None):
+        return self._cast(
+            super(benedict, self).setdefault(key, default))
+
     def rename(self, key, key_new):
         """
         Rename a dict item key from 'key' to 'key_new'.
